#!/bin/env python

from netCDF4 import Dataset
import matplotlib.pyplot as plt

nc_l1b = Dataset('l1b_ref.nc')
nc_l1c = Dataset('l1c_ref.nc')
target_viewport = 4
target_wave = 40

l1b_radiance = nc_l1b['OBSERVATION_DATA/I'][:, :, target_wave]
l1b_dolp = nc_l1b['OBSERVATION_DATA/DoLP'][:, :, target_wave]
l1c_radiance = nc_l1c['observation_data/I'][:, :, target_viewport, target_wave]
l1c_dolp = nc_l1c['observation_data/DOLP'][:, :, target_viewport, target_wave]

fontsize = 30
plt.rcParams['font.size'] = fontsize
fig, axs = plt.subplots(1, 4, figsize=(30, 15))

ax = axs[0]
ax.set_title('L1B radiance')
psm = ax.pcolormesh(l1b_radiance, vmin=0, vmax=0.07)
fig.colorbar(psm, ax=ax)
ax.set_xlabel('ACT index')
ax.set_ylabel('ALT index')

ax = axs[1]
ax.set_title('L1B DoLP')
psm = ax.pcolormesh(l1b_dolp, vmin=0, vmax=0.07)
fig.colorbar(psm, ax=ax)
ax.set_xlabel('ACT index')
ax.set_ylabel('ALT index')

ax = axs[2]
ax.set_title('L1C radiance')
psm = ax.pcolormesh(l1c_radiance, vmin=0, vmax=0.07)
fig.colorbar(psm, ax=ax)
ax.set_xlabel('ACT index')
ax.set_ylabel('ALT index')

ax = axs[3]
ax.set_title('L1C DoLP')
psm = ax.pcolormesh(l1c_dolp, vmin=0, vmax=0.07)
fig.colorbar(psm, ax=ax)
ax.set_xlabel('ACT index')
ax.set_ylabel('ALT index')

plt.tight_layout()
plt.show()
